DateInputFormatter class

An implementation of TextInputFormatter provides a way to input date form with TextField, such as dd/MM/yyyy. In order to guide user about input form, the formatter will provide TextField a placeholder --/--/---- as soon as user start editing. During editing session, the formatter will replace appropriate placeholder characters by user's input.

Inheritance

Constructors

DateInputFormatter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited